@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: RepeatedTest.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: RepeatedTest.php 1985 2007-12-26 18:11:55Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
@@ -56,29 +56,50 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
 class PHPUnit_Extensions_RepeatedTest extends PHPUnit_Extensions_TestDecorator
 {
     /**
-     * @var    integer
-     * @access private
+     * @var    mixed
+     * @access protected
      */
-    private $timesRepeat = 1;
+    protected $filter = FALSE;
+
+    /**
+     * @var    array
+     * @access protected
+     */
+    protected $groups = array();
+
+    /**
+     * @var    array
+     * @access protected
+     */
+    protected $excludeGroups = array();
+
+    /**
+     * @var    integer
+     * @access protected
+     */
+    protected $timesRepeat = 1;
 
     /**
      * Constructor.
      *
      * @param  PHPUnit_Framework_Test $test
-     * @param  integer                 $timesRepeat
+     * @param  integer                $timesRepeat
+     * @param  mixed                  $filter
+     * @param  array                  $groups
+     * @param  array                  $excludeGroups
      * @throws InvalidArgumentException
      * @access public
      */
-    public function __construct(PHPUnit_Framework_Test $test, $timesRepeat = 1)
+    public function __construct(PHPUnit_Framework_Test $test, $timesRepeat = 1, $filter = FALSE, array $groups = array(), array $excludeGroups = array())
     {
         parent::__construct($test);
 
@@ -90,6 +111,10 @@ class PHPUnit_Extensions_RepeatedTest extends PHPUnit_Extensions_TestDecorator
               'Argument 2 must be a positive integer.'
             );
         }
+
+        $this->filter        = $filter;
+        $this->groups        = $groups;
+        $this->excludeGroups = $excludeGroups;
     }
 
     /**
@@ -120,7 +145,13 @@ class PHPUnit_Extensions_RepeatedTest extends PHPUnit_Extensions_TestDecorator
         }
 
         for ($i = 0; $i < $this->timesRepeat && !$result->shouldStop(); $i++) {
-            $this->test->run($result);
+            if ($this->test instanceof PHPUnit_Framework_TestSuite) {
+                $this->test->run(
+                  $result, $this->filter, $this->groups, $this->excludeGroups
+                );
+            } else {
+                $this->test->run($result);
+            }
         }
 
         return $result;
