@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,17 +37,20 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: TestSuite.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: TestSuite.php 2645 2008-03-21 12:23:36Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
 require_once 'PHPUnit/Framework.php';
 require_once 'PHPUnit/Runner/BaseTestRunner.php';
+require_once 'PHPUnit/Util/Class.php';
 require_once 'PHPUnit/Util/Fileloader.php';
 require_once 'PHPUnit/Util/Filter.php';
+require_once 'PHPUnit/Util/Test.php';
+require_once 'PHPUnit/Util/TestSuiteIterator.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
 
@@ -84,37 +87,53 @@ if (!class_exists('PHPUnit_Framework_TestSuite', FALSE)) {
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
-class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Framework_SelfDescribing
+class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Framework_SelfDescribing, IteratorAggregate
 {
+    /**
+     * Fixture that is shared between the tests of this test suite.
+     *
+     * @var    mixed
+     * @access protected
+     */
+    protected $sharedFixture;
+
     /**
      * The name of the test suite.
      *
      * @var    string
-     * @access private
+     * @access protected
      */
-    private $name = '';
+    protected $name = '';
+
+    /**
+     * The test groups of the test suite.
+     *
+     * @var    array
+     * @access protected
+     */
+    protected $groups = array();
 
     /**
      * The tests in the test suite.
      *
      * @var    array
-     * @access private
+     * @access protected
      */
-    private $tests = array();
+    protected $tests = array();
 
     /**
      * The number of tests in the test suite.
      *
      * @var    integer
-     * @access private
+     * @access protected
      */
-    private $numTests = -1;
+    protected $numTests = -1;
 
     /**
      * Constructs a new TestSuite:
@@ -195,10 +214,19 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
             return;
         }
 
-        $names = array();
+        $className   = $theClass->getName();
+        $names       = array();
+        $classGroups = PHPUnit_Util_Test::getGroups($theClass);
 
         foreach ($theClass->getMethods() as $method) {
-            $this->addTestMethod($method, $names, $theClass);
+            if (strpos($method->getDeclaringClass()->getName(), 'PHPUnit_') !== 0) {
+                $this->addTestMethod(
+                  $method,
+                  PHPUnit_Util_Test::getGroups($method, $classGroups),
+                  $names,
+                  $theClass
+                );
+            }
         }
 
         if (empty($this->tests)) {
@@ -229,12 +257,29 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
      * Adds a test to the suite.
      *
      * @param  PHPUnit_Framework_Test $test
+     * @param  array                  $groups
      * @access public
      */
-    public function addTest(PHPUnit_Framework_Test $test)
+    public function addTest(PHPUnit_Framework_Test $test, $groups = array())
     {
         $this->tests[]  = $test;
         $this->numTests = -1;
+
+        if ($test instanceof PHPUnit_Framework_TestSuite && empty($groups)) {
+            $groups = $test->getGroups();
+        }
+
+        if (empty($groups)) {
+            $groups = array('__nogroup__');
+        }
+
+        foreach ($groups as $group) {
+            if (!isset($this->groups[$group])) {
+                $this->groups[$group] = array($test);
+            } else {
+                $this->groups[$group][] = $test;
+            }
+        }
     }
 
     /**
@@ -246,7 +291,7 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
      */
     public function addTestSuite($testClass)
     {
-        if (is_string($testClass) && class_exists($testClass, FALSE)) {
+        if (is_string($testClass) && class_exists($testClass)) {
             $testClass = new ReflectionClass($testClass);
         }
 
@@ -259,7 +304,24 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
         }
 
         else if ($testClass instanceof ReflectionClass) {
-            $this->addTest(new PHPUnit_Framework_TestSuite($testClass));
+            $suiteMethod = FALSE;
+
+            if (!$testClass->isAbstract()) {
+                if ($testClass->hasMethod(PHPUnit_Runner_BaseTestRunner::SUITE_METHODNAME)) {
+                    $method = $testClass->getMethod(
+                      PHPUnit_Runner_BaseTestRunner::SUITE_METHODNAME
+                    );
+
+                    if ($method->isStatic()) {
+                        $this->addTest($method->invoke(NULL, $testClass->getName()));
+                        $suiteMethod = TRUE;
+                    }
+                }
+            }
+
+            if (!$suiteMethod) {
+                $this->addTest(new PHPUnit_Framework_TestSuite($testClass));
+            }
         }
 
         else {
@@ -276,19 +338,33 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
      * leaving the current test run untouched.
      *
      * @param  string  $filename
+     * @param  boolean $syntaxCheck
+     * @param  array   $phptOptions Array with ini settings for the php instance
+     *                              run, key being the name if the setting,
+     *                              value the ini value.
      * @throws InvalidArgumentException
      * @access public
      * @since  Method available since Release 2.3.0
      * @author Stefano F. Rausch <stefano@rausch-e.net>
      */
-    public function addTestFile($filename)
+    public function addTestFile($filename, $syntaxCheck = TRUE, $phptOptions = array())
     {
         if (!is_string($filename)) {
             throw new InvalidArgumentException;
         }
 
+        if (file_exists($filename) && substr($filename, -5) == '.phpt') {
+            require_once 'PHPUnit/Extensions/PhptTestCase.php';
+
+            $this->addTest(
+              new PHPUnit_Extensions_PhptTestCase($filename, $phptOptions)
+            );
+
+            return;
+        }
+
         if (!file_exists($filename)) {
-            $includePaths = PHPUnit_Util_Fileloader::getIncludePaths();
+            $includePaths = explode(PATH_SEPARATOR, get_include_path());
 
             foreach ($includePaths as $includePath) {
                 $file = $includePath . DIRECTORY_SEPARATOR . $filename;
@@ -300,13 +376,9 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
             }
         }
 
-        $declaredClasses = get_declared_classes();
-
-        PHPUnit_Util_Fileloader::checkAndLoad($filename);
-
-        $newClasses = array_values(
-          array_diff(get_declared_classes(), $declaredClasses)
-        );
+        PHPUnit_Util_Class::collectStart();
+        PHPUnit_Util_Fileloader::checkAndLoad($filename, $syntaxCheck);
+        $newClasses = PHPUnit_Util_Class::collectEnd();
 
         $testsFound = FALSE;
 
@@ -320,7 +392,7 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
                     );
 
                     if ($method->isStatic()) {
-                        $this->addTest($method->invoke(NULL));
+                        $this->addTest($method->invoke(NULL, $className));
 
                         $testsFound = TRUE;
                     }
@@ -348,15 +420,20 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
     /**
      * Wrapper for addTestFile() that adds multiple test files.
      *
-     * @param  array $filenames
+     * @param  array|Iterator $filenames
      * @throws InvalidArgumentException
      * @access public
      * @since  Method available since Release 2.3.0
      */
-    public function addTestFiles(array $filenames)
+    public function addTestFiles($filenames)
     {
+        if (!(is_array($filenames) ||
+             (is_object($filenames) && $filenames instanceof Iterator))) {
+            throw new InvalidArgumentException;
+        }
+
         foreach ($filenames as $filename) {
-            $this->addTestFile($filename);
+            $this->addTestFile((string)$filename);
         }
     }
 
@@ -390,39 +467,82 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
      */
     public static function createTest(ReflectionClass $theClass, $name)
     {
+        $className  = $theClass->getName();
+        $method     = new ReflectionMethod($className, $name);
+        $docComment = $method->getDocComment();
+
         if (!$theClass->isInstantiable()) {
             return self::warning(
-              sprintf(
-                'Cannot instantiate class "%s".',
-                $theClass->getName()
-              )
+              sprintf('Cannot instantiate class "%s".', $className)
             );
         }
 
+        // @expectedException ExceptionClass              on TestCase::testMethod()
+        // @expectedException ExceptionClass message      on TestCase::testMethod()
+        // @expectedException ExceptionClass message code on TestCase::testMethod()
+        if (preg_match('(@expectedException\s+([:.\w]+)(?:[\t ]+(\S*))?(?:[\t ]+(\S*))?\s*$)m', $docComment, $matches)) {
+            $expectedException = $matches[1];
+
+            if (isset($matches[2])) {
+                $expectedExceptionMessage = trim($matches[2]);
+            } else {
+                $expectedExceptionMessage = '';
+            }
+
+            if (isset($matches[3])) {
+                $expectedExceptionCode = (int)$matches[3];
+            } else {
+                $expectedExceptionCode = 0;
+            }
+        }
+
         $constructor = $theClass->getConstructor();
 
         if ($constructor !== NULL) {
             $parameters = $constructor->getParameters();
 
-            if (count($parameters) == 0) {
-                $test = $theClass->newInstance();
+            // TestCase() or TestCase($name)
+            if (count($parameters) < 2) {
+                $test = new $className;
+            }
 
-                if ($test instanceof PHPUnit_Framework_TestCase) {
-                    $test->setName($name);
+            // TestCase($name, $data)
+            else {
+                $data = PHPUnit_Util_Test::getProvidedData($className, $name);
+
+                if (is_array($data) || $data instanceof Iterator) {
+                     $test = new PHPUnit_Framework_TestSuite(
+                       $className . '::' . $name
+                     );
+
+                    foreach ($data as $_dataName => $_data) {
+                        $_test = new $className($name, $_data, $_dataName);
+
+                        if ($_test instanceof PHPUnit_Framework_TestCase &&
+                            isset($expectedException)) {
+                            $_test->setExpectedException(
+                              $expectedException,
+                              $expectedExceptionMessage,
+                              $expectedExceptionCode
+                            );
+                        }
+
+                        $test->addTest($_test);
+                    }
+                } else {
+                    $test = new $className;
                 }
             }
+        }
 
-            else if (count($parameters) == 1 &&
-                     $parameters[0]->getClass() === NULL) {
-                $test = $theClass->newInstance($name);
-            }
+        if ($test instanceof PHPUnit_Framework_TestCase) {
+            $test->setName($name);
 
-            else {
-                return self::warning(
-                  sprintf(
-                    'Constructor of class "%s" is not TestCase($name) or TestCase().',
-                    $theClass->getName()
-                  )
+            if (isset($expectedException)) {
+                $test->setExpectedException(
+                  $expectedException,
+                  $expectedExceptionMessage,
+                  $expectedExceptionCode
                 );
             }
         }
@@ -452,30 +572,79 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
         return $this->name;
     }
 
+    /**
+     * Returns the test groups of the suite.
+     *
+     * @return array
+     * @access public
+     * @since  Method available since Release 3.2.0
+     */
+    public function getGroups()
+    {
+        return array_keys($this->groups);
+    }
+
     /**
      * Runs the tests and collects their result in a TestResult.
      *
      * @param  PHPUnit_Framework_TestResult $result
      * @param  mixed                        $filter
+     * @param  array                        $groups
+     * @param  array                        $excludeGroups
      * @return PHPUnit_Framework_TestResult
      * @throws InvalidArgumentException
      * @access public
      */
-    public function run(PHPUnit_Framework_TestResult $result = NULL, $filter = FALSE)
+    public function run(PHPUnit_Framework_TestResult $result = NULL, $filter = FALSE, array $groups = array(), array $excludeGroups = array())
     {
         if ($result === NULL) {
             $result = $this->createResult();
         }
 
+        try {
+            $this->setUp();
+        }
+
+        catch (PHPUnit_Framework_SkippedTestSuiteError $e) {
+            $numTests = count($this);
+
+            for ($i = 0; $i < $numTests; $i++) {
+                $result->addFailure($this, $e, 0);
+            }
+
+            return $result;
+        }
+
         $result->startTestSuite($this);
 
-        foreach ($this->tests as $test) {
+        $tests = array();
+
+        if (empty($excludeGroups)) {
+            if (empty($groups)) {
+                $tests = $this->tests;
+            } else {
+                foreach ($groups as $group) {
+                    if (isset($this->groups[$group])) {
+                        $tests = array_merge($tests, $this->groups[$group]);
+                    }
+                }
+            }
+        } else {
+            foreach ($this->groups as $_group => $_tests) {
+                if (!in_array($_group, $excludeGroups)) {
+                    $tests = array_merge($tests, $_tests);
+                }
+            }
+        }
+
+        foreach ($tests as $test) {
             if ($result->shouldStop()) {
                 break;
             }
 
             if ($test instanceof PHPUnit_Framework_TestSuite) {
-                $test->run($result, $filter);
+                $test->setSharedFixture($this->sharedFixture);
+                $test->run($result, $filter, $groups, $excludeGroups);
             } else {
                 $runTest = TRUE;
 
@@ -488,12 +657,17 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
                 }
 
                 if ($runTest) {
+                    if ($test instanceof PHPUnit_Framework_TestCase) {
+                        $test->setSharedFixture($this->sharedFixture);
+                    }
+
                     $this->runTest($test, $result);
                 }
             }
         }
 
         $result->endTestSuite($this);
+        $this->tearDown();
 
         return $result;
     }
@@ -537,17 +711,6 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
         }
     }
 
-    /**
-     * Returns the number of tests in this suite.
-     *
-     * @return integer
-     * @access public
-     */
-    public function testCount()
-    {
-        return count($this->tests);
-    }
-
     /**
      * Returns the tests as an enumeration.
      *
@@ -559,13 +722,27 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
         return $this->tests;
     }
 
+    /**
+     * Mark the test suite as skipped.
+     *
+     * @param  string  $message
+     * @throws PHPUnit_Framework_SkippedTestSuiteError
+     * @access public
+     * @since  Method available since Release 3.0.0
+     */
+    public function markTestSuiteSkipped($message = '')
+    {
+        throw new PHPUnit_Framework_SkippedTestSuiteError($message);
+    }
+
     /**
      * @param  ReflectionMethod $method
+     * @param  string           $groups
      * @param  array            $names
      * @param  ReflectionClass  $theClass
-     * @access private
+     * @access protected
      */
-    private function addTestMethod(ReflectionMethod $method, Array &$names, ReflectionClass $theClass)
+    protected function addTestMethod(ReflectionMethod $method, $groups, Array &$names, ReflectionClass $theClass)
     {
         $name = $method->getName();
 
@@ -580,7 +757,8 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
               self::createTest(
                 $theClass,
                 $name
-              )
+              ),
+              $groups
             );
         }
 
@@ -600,37 +778,89 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
     /**
      * @param  ReflectionMethod $method
      * @return boolean
-     * @access private
+     * @access public
+     * @static
      */
-    private function isPublicTestMethod(ReflectionMethod $method)
+    public static function isPublicTestMethod(ReflectionMethod $method)
     {
-        return ($this->isTestMethod($method) &&
-                $method->isPublic());
+        return (self::isTestMethod($method) && $method->isPublic());
     }
 
     /**
      * @param  ReflectionMethod $method
      * @return boolean
-     * @access private
+     * @access public
+     * @static
      */
-    private function isTestMethod(ReflectionMethod $method)
+    public static function isTestMethod(ReflectionMethod $method)
     {
-        if (substr($method->name, 0, 4) == 'test') {
+        if (strpos($method->name, 'test') === 0) {
             return TRUE;
         }
 
-        return strpos($method->getDocComment(), '@test') !== FALSE;
+        // @scenario on TestCase::testMethod()
+        // @test     on TestCase::testMethod()
+        return strpos($method->getDocComment(), '@test')     !== FALSE ||
+               strpos($method->getDocComment(), '@scenario') !== FALSE;
     }
 
     /**
      * @param  string  $message
      * @return PHPUnit_Framework_Warning
-     * @access private
+     * @access protected
      */
-    private static function warning($message)
+    protected static function warning($message)
     {
         return new PHPUnit_Framework_Warning($message);
     }
+
+    /**
+     * Sets the shared fixture for the tests of this test suite.
+     *
+     * @param  mixed $sharedFixture
+     * @access public
+     * @since  Method available since Release 3.1.0
+     */
+    public function setSharedFixture($sharedFixture)
+    {
+        $this->sharedFixture = $sharedFixture;
+    }
+
+    /**
+     * Returns an iterator for this test suite.
+     *
+     * @return RecursiveIteratorIterator
+     * @access public
+     * @since  Method available since Release 3.1.0
+     */
+    public function getIterator()
+    {
+        return new RecursiveIteratorIterator(
+          new PHPUnit_Util_TestSuiteIterator($this)
+        );
+    }
+
+    /**
+     * Template Method that is called before the tests
+     * of this test suite are run.
+     *
+     * @access protected
+     * @since  Method available since Release 3.1.0
+     */
+    protected function setUp()
+    {
+    }
+
+    /**
+     * Template Method that is called after the tests
+     * of this test suite have finished running.
+     *
+     * @access protected
+     * @since  Method available since Release 3.1.0
+     */
+    protected function tearDown()
+    {
+    }
 }
 
 }
