@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Warning.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: Warning.php 1985 2007-12-26 18:11:55Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
@@ -57,9 +57,9 @@ if (!class_exists('PHPUnit_Framework_Warning', FALSE)) {
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -67,9 +67,9 @@ class PHPUnit_Framework_Warning extends PHPUnit_Framework_TestCase
 {
     /**
      * @var    string
-     * @access private
+     * @access protected
      */
-    private $message = '';
+    protected $message = '';
 
     /**
      * @param  string  $message
