@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: BankAccountTest.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: BankAccountTest.php 1985 2007-12-26 18:11:55Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
  */
@@ -53,36 +53,23 @@ require_once 'BankAccount.php';
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.3.0
  */
 class BankAccountTest extends PHPUnit_Framework_TestCase
 {
-    /**
-     * BankAccount object used as the tests' fixture.
-     *
-     * @var    BankAccount
-     * @access private
-     */
-    private $ba;
+    protected $ba;
 
-    /**
-     * Sets up the test fixture.
-     *
-     * @access protected
-     */
     protected function setUp()
     {
         $this->ba = new BankAccount;
     }
 
     /**
-     * Asserts that the balance is initially zero.
-     *
-     * @access public
+     * @covers BankAccount::getBalance
      */
     public function testBalanceIsInitiallyZero()
     {
@@ -90,9 +77,7 @@ class BankAccountTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * Asserts that the balance cannot become negative.
-     *
-     * @access public
+     * @covers BankAccount::withdrawMoney
      */
     public function testBalanceCannotBecomeNegative()
     {
@@ -100,7 +85,9 @@ class BankAccountTest extends PHPUnit_Framework_TestCase
             $this->ba->withdrawMoney(1);
         }
 
-        catch (InvalidArgumentException $e) {
+        catch (BankAccountException $e) {
+            $this->assertEquals(0, $this->ba->getBalance());
+
             return;
         }
 
@@ -108,9 +95,7 @@ class BankAccountTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * Asserts that the balance cannot become negative.
-     *
-     * @access public
+     * @covers BankAccount::depositMoney
      */
     public function testBalanceCannotBecomeNegative2()
     {
@@ -118,7 +103,9 @@ class BankAccountTest extends PHPUnit_Framework_TestCase
             $this->ba->depositMoney(-1);
         }
 
-        catch (InvalidArgumentException $e) {
+        catch (BankAccountException $e) {
+            $this->assertEquals(0, $this->ba->getBalance());
+
             return;
         }
 
@@ -126,21 +113,19 @@ class BankAccountTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * Asserts that the balance cannot become negative.
-     *
-     * @access public
+     * @covers BankAccount::getBalance
+     * @covers BankAccount::depositMoney
+     * @covers BankAccount::withdrawMoney
      */
-    public function testBalanceCannotBecomeNegative3()
+/*
+    public function testDepositWithdrawMoney()
     {
-        try {
-            $this->ba->setBalance(-1);
-        }
-
-        catch (InvalidArgumentException $e) {
-            return;
-        }
-
-        $this->fail();
+        $this->assertEquals(0, $this->ba->getBalance());
+        $this->ba->depositMoney(1);
+        $this->assertEquals(1, $this->ba->getBalance());
+        $this->ba->withdrawMoney(1);
+        $this->assertEquals(0, $this->ba->getBalance());
     }
+*/
 }
 ?>
