@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,24 +37,26 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: ConstraintTest.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: ConstraintTest.php 2396 2008-02-09 16:07:59Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
 
 require_once 'PHPUnit/Framework/TestCase.php';
 
+require_once '_files/ClassWithNonPublicAttributes.php';
+
 /**
  *
  *
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -83,6 +85,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintArrayHasKey2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_ArrayHasKey(0);
+
+        try {
+            $constraint->fail(array(), 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nArray\n(\n)\n has key <integer:0>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintArrayNotHasKey()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -108,6 +130,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintArrayNotHasKey2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_ArrayHasKey(0)
+        );
+
+        try {
+            $constraint->fail(array(0), 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nArray\n(\n    [0] => 0\n)\n does not have key <integer:0>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintFileExists()
     {
         $constraint = new PHPUnit_Framework_Constraint_FileExists;
@@ -131,6 +175,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintFileExists2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_FileExists;
+
+        try {
+            $constraint->fail('foo', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that file \"foo\" exists.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintFileNotExists()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -156,6 +220,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintFileNotExists2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_FileExists
+        );
+
+        try {
+            $constraint->fail('foo', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that file \"foo\" does not exist.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintGreaterThan()
     {
         $constraint = new PHPUnit_Framework_Constraint_GreaterThan(1);
@@ -180,6 +266,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintGreaterThan2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_GreaterThan(1);
+
+        try {
+            $constraint->fail(0, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:0> is greater than <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintNotGreaterThan()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -205,6 +311,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintNotGreaterThan2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_GreaterThan(1)
+        );
+
+        try {
+            $constraint->fail(1, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:1> is not greater than <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsAnything()
     {
         $constraint = new PHPUnit_Framework_Constraint_IsAnything;
@@ -249,6 +377,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsEqual2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_IsEqual(1);
+
+        try {
+            $constraint->fail(0, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:0> is equal to <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsNotEqual()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -275,6 +423,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsNotEqual2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_IsEqual(1)
+        );
+
+        try {
+            $constraint->fail(1, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:1> is not equal to <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsIdentical()
     {
         $a = new stdClass;
@@ -302,6 +472,29 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsIdentical2()
+    {
+        $a = new stdClass;
+        $b = new stdClass;
+
+        $constraint = new PHPUnit_Framework_Constraint_IsIdentical($a);
+
+        try {
+            $constraint->fail($b, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nstdClass Object\n(\n)\n is identical to \nstdClass Object\n(\n)\n.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsNotIdentical()
     {
         $a = new stdClass;
@@ -331,6 +524,30 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsNotIdentical2()
+    {
+        $a = new stdClass;
+
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_IsIdentical($a)
+        );
+
+        try {
+            $constraint->fail($a, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nstdClass Object\n(\n)\n is not identical to \nstdClass Object\n(\n)\n.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsInstanceOf()
     {
         $constraint = new PHPUnit_Framework_Constraint_IsInstanceOf('Exception');
@@ -345,7 +562,27 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
 
         catch (PHPUnit_Framework_ExpectationFailedException $e) {
             $this->assertEquals(
-              "Failed asserting that \nstdClass Object\n(\n)\n is instance of class \"Exception\".",
+              'Failed asserting that <stdClass> is an instance of class "Exception".',
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
+    public function testConstraintIsInstanceOf2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_IsInstanceOf('Exception');
+
+        try {
+            $constraint->fail(new stdClass, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <stdClass> is an instance of class \"Exception\".",
               $e->getDescription()
             );
 
@@ -371,7 +608,29 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
 
         catch (PHPUnit_Framework_ExpectationFailedException $e) {
             $this->assertEquals(
-              "Failed asserting that \nstdClass Object\n(\n)\n is not instance of class \"stdClass\".",
+              'Failed asserting that <stdClass> is not an instance of class "stdClass".',
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
+    public function testConstraintIsNotInstanceOf2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_IsInstanceOf('stdClass')
+        );
+
+        try {
+            $constraint->fail(new stdClass, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <stdClass> is not an instance of class \"stdClass\".",
               $e->getDescription()
             );
 
@@ -405,6 +664,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsType2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_IsType('string');
+
+        try {
+            $constraint->fail(new stdClass, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nstdClass Object\n(\n)\n is of type \"string\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintIsNotType()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -431,6 +710,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintIsNotType2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_IsType('string')
+        );
+
+        try {
+            $constraint->fail('', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <string:> is not of type \"string\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintLessThan()
     {
         $constraint = new PHPUnit_Framework_Constraint_LessThan(1);
@@ -455,6 +756,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintLessThan2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_LessThan(1);
+
+        try {
+            $constraint->fail(0, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:0> is less than <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintNotLessThan()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -480,6 +801,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintNotLessThan2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_LessThan(1)
+        );
+
+        try {
+            $constraint->fail(1, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <integer:1> is not less than <integer:1>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintObjectHasAttribute()
     {
         $constraint = new PHPUnit_Framework_Constraint_ObjectHasAttribute('foo');
@@ -503,6 +846,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintObjectHasAttribute2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_ObjectHasAttribute('foo');
+
+        try {
+            $constraint->fail(new stdClass, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nstdClass Object\n(\n)\n has attribute \"foo\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintObjectNotHasAttribute()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -531,6 +894,31 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintObjectNotHasAttribute2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_ObjectHasAttribute('foo')
+        );
+
+        $o = new stdClass;
+        $o->foo = 'bar';
+
+        try {
+            $constraint->fail($o, 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nstdClass Object\n(\n    [foo] => bar\n)\n does not have attribute \"foo\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintPCREMatch()
     {
         $constraint = new PHPUnit_Framework_Constraint_PCREMatch('/foo/');
@@ -555,6 +943,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintPCREMatch2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_PCREMatch('/foo/');
+
+        try {
+            $constraint->fail('barbazbar', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <string:barbazbar> matches PCRE pattern \"/foo/\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintPCRENotMatch()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -581,6 +989,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintPCRENotMatch2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_PCREMatch('/foo/')
+        );
+
+        try {
+            $constraint->fail('barfoobar', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <string:barfoobar> does not match PCRE pattern \"/foo/\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintStringContains()
     {
         $constraint = new PHPUnit_Framework_Constraint_StringContains('foo');
@@ -605,6 +1035,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintStringContains2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_StringContains('foo');
+
+        try {
+            $constraint->fail('barbazbar', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <string:barbazbar> contains \"foo\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintStringNotContains()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -631,6 +1081,28 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintStringNotContains2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_StringContains('foo')
+        );
+
+        try {
+            $constraint->fail('barfoobar', 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that <string:barfoobar> does not contain \"foo\".",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintTraversableContains()
     {
         $constraint = new PHPUnit_Framework_Constraint_TraversableContains('foo');
@@ -655,6 +1127,26 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
         $this->fail();
     }
 
+    public function testConstraintTraversableContains2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_TraversableContains('foo');
+
+        try {
+            $constraint->fail(array('bar'), 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nArray\n(\n    [0] => bar\n)\n contains <string:foo>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testConstraintTraversableNotContains()
     {
         $constraint = new PHPUnit_Framework_Constraint_Not(
@@ -680,5 +1172,27 @@ class Framework_ConstraintTest extends PHPUnit_Framework_TestCase
 
         $this->fail();
     }
+
+    public function testConstraintTraversableNotContains2()
+    {
+        $constraint = new PHPUnit_Framework_Constraint_Not(
+          new PHPUnit_Framework_Constraint_TraversableContains('foo')
+        );
+
+        try {
+            $constraint->fail(array('foo'), 'custom message');
+        }
+
+        catch (PHPUnit_Framework_ExpectationFailedException $e) {
+            $this->assertEquals(
+              "custom message\nFailed asserting that \nArray\n(\n    [0] => foo\n)\n does not contain <string:foo>.",
+              $e->getDescription()
+            );
+
+            return;
+        }
+
+        $this->fail();
+    }
 }
 ?>
