@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: ErrorHandler.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: ErrorHandler.php 2439 2008-02-14 08:18:31Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
  */
@@ -59,10 +59,30 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  */
 function PHPUnit_Util_ErrorHandler($errno, $errstr, $errfile, $errline)
 {
+    if (!($errno & error_reporting())) {
+        return FALSE;
+    }
+
     $trace = debug_backtrace();
     array_shift($trace);
 
-    throw new PHPUnit_Framework_Error(
+    foreach ($trace as $frame) {
+        if ($frame['function'] == '__toString') {
+            return FALSE;
+        }
+    }
+
+    if ($errno == E_NOTICE || $errno == E_STRICT) {
+        if (PHPUnit_Framework_Notice::$enabled !== TRUE) {
+            return FALSE;
+        }
+
+        $exception = 'PHPUnit_Framework_Notice';
+    } else {
+        $exception = 'PHPUnit_Framework_Error';
+    }
+
+    throw new $exception(
       $errstr,
       $errno,
       $errfile,
