@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: TAP.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: TAP.php 2649 2008-03-21 14:49:18Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -58,9 +58,9 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -68,33 +68,15 @@ class PHPUnit_Util_Log_TAP extends PHPUnit_Util_Printer implements PHPUnit_Frame
 {
     /**
      * @var    integer
-     * @access private
+     * @access protected
      */
-    private $testNumber = 0;
+    protected $testNumber = 0;
 
     /**
      * @var    boolean
-     * @access private
+     * @access protected
      */
-    private $testSuccessful = TRUE;
-
-    /**
-     * Flush buffer and close output.
-     *
-     * @access public
-     */
-    public function flush()
-    {
-        $this->write(
-          sprintf(
-            "1..%s\n",
-
-            $this->testNumber
-          )
-        );
-
-        parent::flush();
-    }
+    protected $testSuccessful = TRUE;
 
     /**
      * An error occurred.
@@ -148,12 +130,14 @@ class PHPUnit_Util_Log_TAP extends PHPUnit_Util_Printer implements PHPUnit_Frame
     {
         $this->write(
           sprintf(
-            "ok %s - # SKIP%s\n",
+            "ok %d - # SKIP%s\n",
 
             $this->testNumber,
             $e->getMessage() != '' ? ' ' . $e->getMessage() : ''
           )
         );
+
+        $this->testSuccessful = FALSE;
     }
 
     /**
@@ -166,8 +150,9 @@ class PHPUnit_Util_Log_TAP extends PHPUnit_Util_Printer implements PHPUnit_Frame
     {
         $this->write(
           sprintf(
-            "# TestSuite \"%s\" started.\n",
+            "1..%d\n# TestSuite \"%s\" started.\n",
 
+            count($suite),
             $suite->getName()
           )
         );
@@ -214,7 +199,7 @@ class PHPUnit_Util_Log_TAP extends PHPUnit_Util_Printer implements PHPUnit_Frame
         if ($this->testSuccessful === TRUE) {
             $this->write(
               sprintf(
-                "ok %s - %s\n",
+                "ok %d - %s\n",
 
                 $this->testNumber,
                 PHPUnit_Util_Test::describe($test)
@@ -225,15 +210,15 @@ class PHPUnit_Util_Log_TAP extends PHPUnit_Util_Printer implements PHPUnit_Frame
 
     /**
      * @param  PHPUnit_Framework_Test $test
-     * @param  string                  $prefix
-     * @param  string                  $directive
-     * @access private
+     * @param  string                 $prefix
+     * @param  string                 $directive
+     * @access protected
      */
-    private function writeNotOk(PHPUnit_Framework_Test $test, $prefix = '', $directive = '')
+    protected function writeNotOk(PHPUnit_Framework_Test $test, $prefix = '', $directive = '')
     {
         $this->write(
           sprintf(
-            "not ok %s - %s%s%s\n",
+            "not ok %d - %s%s%s\n",
 
             $this->testNumber,
             $prefix != '' ? $prefix . ': ' : '',
