@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2007, Sebastian Bergmann <sb@sebastian-bergmann.de>.
+ * Copyright (c) 2002-2008, Sebastian Bergmann <sb@sebastian-bergmann.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,9 @@
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: ResultPrinter.php 537 2007-02-24 06:58:18Z sb $
+ * @version    SVN: $Id: ResultPrinter.php 2144 2008-01-17 10:53:25Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
  */
@@ -57,9 +57,9 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @category   Testing
  * @package    PHPUnit
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
- * @copyright  2002-2007 Sebastian Bergmann <sb@sebastian-bergmann.de>
+ * @copyright  2002-2008 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.0.6
+ * @version    Release: 3.2.16
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.1.0
  * @abstract
@@ -79,10 +79,10 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
     protected $testClass = '';
 
     /**
-     * @var    boolean
+     * @var    integer
      * @access protected
      */
-    protected $testFailed = FALSE;
+    protected $testStatus = FALSE;
 
     /**
      * @var    array
@@ -90,6 +90,24 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     protected $tests = array();
 
+    protected $successful = 0;
+    protected $failed = 0;
+    protected $skipped = 0;
+    protected $incomplete = 0;
+    protected $testTypeOfInterest = 'PHPUnit_Framework_TestCase';
+
+    /**
+     * @var    string
+     * @access protected
+     */
+    protected $currentTestClassPrettified;
+
+    /**
+     * @var    string
+     * @access protected
+     */
+    protected $currentTestMethodPrettified;
+
     /**
      * Constructor.
      *
@@ -117,21 +135,6 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
         parent::flush();
     }
 
-    /**
-     * Abstract Factory.
-     *
-     * @param  string    $type
-     * @param  resource  $out
-     * @throws RuntimeException
-     * @access public
-     * @static
-     */
-    public static function factory($type, $out = NULL)
-    {
-        $class = 'PHPUnit_Util_TestDox_ResultPrinter_' . $type;
-        return new $class($out);
-    }
-
     /**
      * An error occurred.
      *
@@ -142,7 +145,10 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function addError(PHPUnit_Framework_Test $test, Exception $e, $time)
     {
-        $this->testFailed = TRUE;
+        if ($test instanceof $this->testTypeOfInterest) {
+            $this->testStatus = PHPUnit_Runner_BaseTestRunner::STATUS_ERROR;
+            $this->failed++;
+        }
     }
 
     /**
@@ -155,7 +161,10 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function addFailure(PHPUnit_Framework_Test $test, PHPUnit_Framework_AssertionFailedError $e, $time)
     {
-        $this->testFailed = TRUE;
+        if ($test instanceof $this->testTypeOfInterest) {
+            $this->testStatus = PHPUnit_Runner_BaseTestRunner::STATUS_FAILURE;
+            $this->failed++;
+        }
     }
 
     /**
@@ -168,7 +177,10 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function addIncompleteTest(PHPUnit_Framework_Test $test, Exception $e, $time)
     {
-        $this->testFailed = TRUE;
+        if ($test instanceof $this->testTypeOfInterest) {
+            $this->testStatus = PHPUnit_Runner_BaseTestRunner::STATUS_INCOMPLETE;
+            $this->incomplete++;
+        }
     }
 
     /**
@@ -182,7 +194,10 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function addSkippedTest(PHPUnit_Framework_Test $test, Exception $e, $time)
     {
-        $this->testFailed = TRUE;
+        if ($test instanceof $this->testTypeOfInterest) {
+            $this->testStatus = PHPUnit_Runner_BaseTestRunner::STATUS_SKIPPED;
+            $this->skipped++;
+        }
     }
 
     /**
@@ -215,20 +230,24 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function startTest(PHPUnit_Framework_Test $test)
     {
-        $class = get_class($test);
+        if ($test instanceof $this->testTypeOfInterest) {
+            $class = get_class($test);
 
-        if ($this->testClass != $class) {
-            if ($this->testClass != '') {
-                $this->doEndClass();
+            if ($this->testClass != $class) {
+                if ($this->testClass != '') {
+                    $this->doEndClass();
+                }
+
+                $this->currentTestClassPrettified = $this->prettifier->prettifyTestClass($class);
+                $this->startClass($class);
+
+                $this->testClass = $class;
+                $this->tests     = array();
             }
 
-            $this->startClass($this->prettifier->prettifyTestClass($class));
-
-            $this->testClass = $class;
-            $this->tests     = array();
+            $this->currentTestMethodPrettified = $this->prettifier->prettifyTestMethod($test->getName());
+            $this->testStatus                  = PHPUnit_Runner_BaseTestRunner::STATUS_PASSED;
         }
-
-        $this->testFailed = FALSE;
     }
 
     /**
@@ -240,30 +259,33 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      */
     public function endTest(PHPUnit_Framework_Test $test, $time)
     {
-        $prettifiedName = $this->prettifier->prettifyTestMethod($test->getName());
+        if ($test instanceof $this->testTypeOfInterest) {
+            if (!isset($this->tests[$this->currentTestMethodPrettified])) {
+                if ($this->testStatus == PHPUnit_Runner_BaseTestRunner::STATUS_PASSED) {
+                    $this->tests[$this->currentTestMethodPrettified]['success'] = 1;
+                    $this->tests[$this->currentTestMethodPrettified]['failure'] = 0;
+                } else {
+                    $this->tests[$this->currentTestMethodPrettified]['success'] = 0;
+                    $this->tests[$this->currentTestMethodPrettified]['failure'] = 1;
+                }
+            } else {
+                if ($this->testStatus == PHPUnit_Runner_BaseTestRunner::STATUS_PASSED) {
+                    $this->tests[$this->currentTestMethodPrettified]['success']++;
+                } else {
+                    $this->tests[$this->currentTestMethodPrettified]['failure']++;
+                }
+            }
 
-        if (!isset($this->tests[$prettifiedName])) {
-            if (!$this->testFailed) {
-                $this->tests[$prettifiedName]['success'] = 1;
-                $this->tests[$prettifiedName]['failure'] = 0;
-            } else {
-                $this->tests[$prettifiedName]['success'] = 0;
-                $this->tests[$prettifiedName]['failure'] = 1;
-            }
-        } else {
-            if (!$this->testFailed) {
-                $this->tests[$prettifiedName]['success']++;
-            } else {
-                $this->tests[$prettifiedName]['failure']++;
-            }
+            $this->currentTestClassPrettified  = NULL;
+            $this->currentTestMethodPrettified = NULL;
         }
     }
 
     /**
-     * @access private
+     * @access protected
      * @since  Method available since Release 2.3.0
      */
-    private function doEndClass()
+    protected function doEndClass()
     {
         foreach ($this->tests as $name => $data) {
             if ($data['failure'] == 0) {
@@ -271,7 +293,7 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
             }
         }
 
-        $this->endClass($this->prettifier->prettifyTestClass($this->testClass));
+        $this->endClass($this->testClass);
     }
 
     /**
@@ -288,27 +310,30 @@ abstract class PHPUnit_Util_TestDox_ResultPrinter extends PHPUnit_Util_Printer i
      *
      * @param  string $name
      * @access protected
-     * @abstract
      */
-    abstract protected function startClass($name);
+    protected function startClass($name)
+    {
+    }
 
     /**
      * Handler for 'on test' event.
      *
      * @param  string $name
      * @access protected
-     * @abstract
      */
-    abstract protected function onTest($name);
+    protected function onTest($name)
+    {
+    }
 
     /**
      * Handler for 'end class' event.
      *
      * @param  string $name
      * @access protected
-     * @abstract
      */
-    abstract protected function endClass($name);
+    protected function endClass($name)
+    {
+    }
 
     /**
      * Handler for 'end run' event.
